# Generated by Django 3.2.12 on 2022-02-28 16:08

import datetime

from django.conf import settings
from django.db import migrations, models

from dateutil.relativedelta import relativedelta


def migrate_data(apps, schema_editor):
    Consent = apps.get_model('subjects', 'Consent')
    Contact = apps.get_model('contacts', 'Contact')

    delta = relativedelta(years=settings.CASTELLUM_FULL_AGE)
    today = datetime.date.today()

    underage_true = []
    underage_false = []
    for consent in Consent.objects.all():
        contact = Contact.objects.get(subject_uuid=consent.subject_id)
        if contact.date_of_birth:
            if contact.date_of_birth + delta > today:
                underage_true.append(consent.pk)
            else:
                underage_false.append(consent.pk)
    Consent.objects.filter(pk__in=underage_true).update(underage_when_given=True)
    Consent.objects.filter(pk__in=underage_false).update(underage_when_given=False)


def noop(*args):
    pass


class Migration(migrations.Migration):

    dependencies = [
        ('subjects', '0034_help_texts'),
    ]

    operations = [
        migrations.AddField(
            model_name='consent',
            name='underage_when_given',
            field=models.BooleanField(null=True, verbose_name='Underage when given'),
            preserve_default=False,
        ),
        migrations.RunPython(migrate_data, noop),
    ]
