# (c) 2018-2022 MPIB <https://www.mpib-berlin.mpg.de/>,
#     2018-2019 MPI-CBS <https://www.cbs.mpg.de/>,
#     2018-2019 MPIP <http://www.psych.mpg.de/>
#
# This file is part of Castellum.
#
# Castellum is free software; you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Castellum is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Castellum. If not, see
# <http://www.gnu.org/licenses/>.

from django import template
from django.utils.translation import gettext_lazy as _

register = template.Library()


@register.filter
def reliability_level(subject):
    subject.annotate_reliability()

    if subject.reliability_total == 0:
        ratio = 0
    else:
        ratio = subject.reliability_issues / subject.reliability_total

    if ratio >= 0.5 and subject.reliability_issues > 1:
        return 'danger'
    elif ratio >= 0.25:
        return 'warning'
    else:
        return 'success'


@register.filter
def reliability_summary(subject):
    subject.annotate_reliability()

    if subject.reliability_total == 0:
        return _('no data so far')
    else:
        return _('{issues} issues in {total} studies').format(
            issues=subject.reliability_issues, total=subject.reliability_total
        )
